import{d as p,H as l,b as n,eu as o,e as a,aC as d,eC as r,ey as _,eE as f,ew as i,v as u}from"./outputWidgets.225dd371.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="c6d8a953-4d6d-48b9-865f-2518969f53d9",e._sentryDebugIdIdentifier="sentry-dbid-c6d8a953-4d6d-48b9-865f-2518969f53d9")}catch{}})();const m={key:0,class:"p-steps p-component"},y={class:"p-steps-list"},b={class:"p-menuitem-link"},g={class:"p-steps-number"},I=p({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const s=e,c=l(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(h,v)=>e.stepsInfo?(n(),o("nav",m,[a("ol",y,[(n(!0),o(d,null,r(c.value,(k,t)=>(n(),o("li",{key:t,class:_(["p-steps-item",{"p-highlight":t+1===e.stepsInfo.current}])},[a("span",b,[a("span",g,f(t+1),1)])],2))),128))])])):i("",!0)}});const C=u(I,[["__scopeId","data-v-c916ecf3"]]);export{C as S};
//# sourceMappingURL=Steps.a7f576f9.js.map
