import{K as n,L as p}from"./repository.5c99e956.js";import{E as a}from"./repository.20c89e3d.js";import{d as s,b as m,c as f,u as e}from"./outputWidgets.225dd371.js";import{l as c}from"./index.82d7df3b.js";import"./asyncComputed.8a54909a.js";import"./workspaces.57178210.js";import"./runnerData.6fca8fdf.js";import"./url.29c1f37b.js";import"./record.b805ac15.js";import"./pubsub.3bce7ea8.js";import"./scripts.30552fdf.js";import"./envVars.fa2414d6.js";import"./api.4e5eb9a5.js";import"./index.cf4c23b9.js";import"./PhCheckCircle.vue.d41a0835.js";import"./PhScroll.vue.0e166121.js";import"./PhWebhooksLogo.vue.ce0ac762.js";import"./ant-design.a00feaec.js";import"./index.86c302fc.js";import"./Modal.0a797886.js";import"./Text.a0f2d781.js";import"./index.8e2737d3.js";import"./index.42c8bfb7.js";import"./index.7439e64c.js";import"./Paragraph.253f2b2e.js";import"./index.497bccda.js";import"./Link.da1b7649.js";import"./Title.bbb77099.js";import"./index.253127ce.js";import"./CollapsePanel.16aa48f2.js";import"./index.ceccdea3.js";import"./index.d8b778bd.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.59a4d09a.js";import"./Card.ed89093a.js";import"./TabPane.3fb3cd2e.js";import"./hasIn.1e38e049.js";import"./vuedraggable.umd.082cb792.js";import"./index.c2deb4e1.js";import"./Form.12e2d16e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="50e06578-13ef-4c48-8a9f-0e46a9f42589",t._sentryDebugIdIdentifier="sentry-dbid-50e06578-13ef-4c48-8a9f-0e46a9f42589")}catch{}})();class d{constructor(o=c){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const to=s({__name:"WorkflowKanban",setup(t){const o=new a,r=new d,i=new p("kanban");return(u,y)=>(m(),f(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{to as default};
//# sourceMappingURL=WorkflowKanban.c77f24f6.js.map
