import{P as u}from"./PlayerNavbar.3b70d609.js";import{g as l}from"./api.9155deab.js";import{a as p}from"./asyncComputed.8a54909a.js";import{W as f}from"./WidgetsFrame.36ac6684.js";import{d as _,eB as y,b as n,eu as g,e as s,u as t,c,ew as d,w as h,eE as m,v as b}from"./outputWidgets.225dd371.js";import"./PhKanban.vue.4b1dfe9e.js";import"./index.82d7df3b.js";import"./pubsub.3bce7ea8.js";import"./repository.20c89e3d.js";import"./Text.a0f2d781.js";import"./index.497bccda.js";import"./Link.da1b7649.js";import"./Paragraph.253f2b2e.js";import"./Title.bbb77099.js";import"./index.b8149c32.js";import"./runnerData.6fca8fdf.js";import"./url.29c1f37b.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new I().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="86345257-d4a4-41af-92db-3c6463261ebf",r._sentryDebugIdIdentifier="sentry-dbid-86345257-d4a4-41af-92db-3c6463261ebf")}catch{}})();const w={class:"error"},v={class:"inner-content"},k=_({__name:"Error",setup(r){const o=y(),{result:e}=p(l),i=()=>{const{status:a}=o.params;switch(a){case"404":return{status:a,message:"Page not found."};case"403":return{status:a,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(a,D)=>(n(),g("div",null,[s("div",w,[t(e)?(n(),c(u,{key:0,"runner-data":t(e)},null,8,["runner-data"])):d("",!0),t(e)?(n(),c(f,{key:1,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh",width:"100%"}},{default:h(()=>[s("div",v,[s("h1",null,m(i().status),1),s("p",null,m(i().message),1)])]),_:1},8,["main-color","theme","font-family"])):d("",!0)])]))}});const I=b(k,[["__scopeId","data-v-15f294c9"]]);export{I as default};
//# sourceMappingURL=Error.ba7a634f.js.map
