import{D as a}from"./DeleteOutlined.f8ba9770.js";import{f as o,eH as f}from"./outputWidgets.225dd371.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="935b136b-8067-4b71-87da-b07bec237322",e._sentryDebugIdIdentifier="sentry-dbid-935b136b-8067-4b71-87da-b07bec237322")}catch{}})();function u(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),r.forEach(function(i){d(e,i,n[i])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var l=function(t,n){var r=u({},t,n.attrs);return o(f,u({},r,{icon:a}),null)};l.displayName="DeleteOutlined";l.inheritAttrs=!1;const s=l;export{s as D};
//# sourceMappingURL=DeleteOutlined.5a058ca4.js.map
