import{U as s,f as p,O as d}from"./outputWidgets.225dd371.js";import{B as f,b as i}from"./Text.a0f2d781.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="69999e2d-137c-4479-851f-f2281860071e",e._sentryDebugIdIdentifier="sentry-dbid-69999e2d-137c-4479-851f-f2281860071e")}catch{}})();const y=()=>d(i(),["component"]),a=(e,r)=>{let{slots:t,attrs:o}=r;const n=s(s(s({},e),{component:"div"}),o);return p(f,n,t)};a.displayName="ATypographyParagraph";a.inheritAttrs=!1;a.props=y();const l=a;export{l as A};
//# sourceMappingURL=Paragraph.253f2b2e.js.map
