import{a as e,A as t,B as s}from"./Text.a0f2d781.js";import{A as o}from"./Link.da1b7649.js";import{A as r}from"./Paragraph.253f2b2e.js";import{A as i}from"./Title.bbb77099.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="f2f5b605-65fa-4aeb-ab21-0847e47fdc16",n._sentryDebugIdIdentifier="sentry-dbid-f2f5b605-65fa-4aeb-ab21-0847e47fdc16")}catch{}})();e.Text=t;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,t),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.497bccda.js.map
