import{d as g,eB as y,o as _,u as e,b as p,c as w,eu as b,f as a,w as o,bf as I,aq as l,bF as x,e as h,eE as k}from"./outputWidgets.225dd371.js";import{I as c}from"./router.8e23138d.js";import"./index.2924e62a.js";import{O as B}from"./organization.b100921a.js";import{a as C}from"./asyncComputed.8a54909a.js";import{A as v}from"./Title.bbb77099.js";import{A}from"./index.8e2737d3.js";import{A as D}from"./index.ceccdea3.js";import{C as N}from"./Card.ed89093a.js";import"./Form.12e2d16e.js";import"./hasIn.1e38e049.js";import"./popupNotifcation.6873325b.js";import"./index.cf4c23b9.js";import"./record.b805ac15.js";import"./pubsub.3bce7ea8.js";import"./Text.a0f2d781.js";import"./TabPane.3fb3cd2e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="8c04f020-779d-4976-979d-355154e838ad",t._sentryDebugIdIdentifier="sentry-dbid-8c04f020-779d-4976-979d-355154e838ad")}catch{}})();const z={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},Y=g({__name:"Billing",setup(t){const r=y().params.organizationId,{loading:f,result:m}=C(()=>B.get(r));_(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const u=()=>c.showNewMessage("I want to upgrade my plan");return(E,V)=>e(f)?(p(),w(e(I),{key:0})):(p(),b("div",z,[a(e(A),{justify:"space-between",align:"center"},{default:o(()=>[a(e(v),{level:3},{default:o(()=>[l("Current plan")]),_:1})]),_:1}),a(e(D),{style:{"margin-top":"0"}}),a(e(N),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(x),{onClick:u},{default:o(()=>[l("Upgrade")]),_:1})]),default:o(()=>{var s,i,d;return[h("div",M,k((d=(i=(s=e(m))==null?void 0:s.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{Y as default};
//# sourceMappingURL=Billing.e290feef.js.map
