import{U as c}from"./outputWidgets.225dd371.js";import{c as i,d as f}from"./index.c4b37b86.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="0bf263fd-4f27-42e6-ab41-2b2bcfebeb92",e._sentryDebugIdIdentifier="sentry-dbid-0bf263fd-4f27-42e6-ab41-2b2bcfebeb92")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:d,TimePicker:b,QuarterPicker:o,RangePicker:a}=i(f),y=c(n,{WeekPicker:r,MonthPicker:t,YearPicker:d,RangePicker:a,TimePicker:b,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.e4fd7234.js.map
