import{u as e,a as u}from"./index.82d7df3b.js";import{d as f,r as l,b as i,eu as c,u as t,c as d,ew as b,f as y}from"./outputWidgets.225dd371.js";import{g}from"./api.9155deab.js";import{K as k,L as _}from"./repository.5c99e956.js";import{P as w}from"./PlayerNavbar.3b70d609.js";import{a as h}from"./asyncComputed.8a54909a.js";import{P as v}from"./repository.20c89e3d.js";import"./pubsub.3bce7ea8.js";import"./runnerData.6fca8fdf.js";import"./url.29c1f37b.js";import"./workspaces.57178210.js";import"./record.b805ac15.js";import"./scripts.30552fdf.js";import"./envVars.fa2414d6.js";import"./api.4e5eb9a5.js";import"./index.cf4c23b9.js";import"./PhCheckCircle.vue.d41a0835.js";import"./PhScroll.vue.0e166121.js";import"./PhWebhooksLogo.vue.ce0ac762.js";import"./ant-design.a00feaec.js";import"./index.86c302fc.js";import"./Modal.0a797886.js";import"./Text.a0f2d781.js";import"./index.8e2737d3.js";import"./index.42c8bfb7.js";import"./index.7439e64c.js";import"./Paragraph.253f2b2e.js";import"./index.497bccda.js";import"./Link.da1b7649.js";import"./Title.bbb77099.js";import"./index.253127ce.js";import"./CollapsePanel.16aa48f2.js";import"./index.ceccdea3.js";import"./index.d8b778bd.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.59a4d09a.js";import"./Card.ed89093a.js";import"./TabPane.3fb3cd2e.js";import"./hasIn.1e38e049.js";import"./vuedraggable.umd.082cb792.js";import"./index.c2deb4e1.js";import"./Form.12e2d16e.js";import"./PhKanban.vue.4b1dfe9e.js";import"./index.b8149c32.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="b9be6a19-c300-45fb-b9fe-daf063f26759",r._sentryDebugIdIdentifier="sentry-dbid-b9be6a19-c300-45fb-b9fe-daf063f26759")}catch{}})();const br=f({__name:"Kanban",setup(r){const o=new v(e),a=new _("kanban"),p=l(e.getUser()),{result:n}=h(g),s=()=>{e.removeUser(),u.push({name:"playerHome"})};return(D,I)=>{var m;return i(),c("div",null,[t(n)?(i(),d(w,{key:0,"runner-data":t(n),"show-kanban":!1,"user-email":(m=p.value)==null?void 0:m.claims.email,onLogout:s},null,8,["runner-data","user-email"])):b("",!0),y(k,{"kanban-repository":t(o),storage:t(a)},null,8,["kanban-repository","storage"])])}}});export{br as default};
//# sourceMappingURL=Kanban.7222fb1e.js.map
