import{d as i,eA as c,b as s,eu as m,u as r,c as d,ew as u,f as _,v as l}from"./outputWidgets.225dd371.js";import{g as f}from"./api.9155deab.js";import{a as b}from"./asyncComputed.8a54909a.js";import{P as g}from"./PlayerNavbar.3b70d609.js";import{H as y}from"./HomeContent.076519a0.js";import"./runnerData.6fca8fdf.js";import"./url.29c1f37b.js";import"./PhKanban.vue.4b1dfe9e.js";import"./index.82d7df3b.js";import"./pubsub.3bce7ea8.js";import"./repository.20c89e3d.js";import"./Text.a0f2d781.js";import"./index.497bccda.js";import"./Link.da1b7649.js";import"./Paragraph.253f2b2e.js";import"./Title.bbb77099.js";import"./index.b8149c32.js";import"./PhArrowSquareOut.vue.32437cf7.js";import"./index.dd556745.js";import"./Card.ed89093a.js";import"./TabPane.3fb3cd2e.js";import"./hasIn.1e38e049.js";import"./index.8e2737d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4be3732c-8946-408e-839c-ec0697542c1b",e._sentryDebugIdIdentifier="sentry-dbid-4be3732c-8946-408e-839c-ec0697542c1b")}catch{}})();const k={class:"page"},w=i({__name:"Home",setup(e){const o=c(),{result:t,loading:n}=b(f),p=a=>{o.push({path:`/${a}`})};return(a,v)=>(s(),m("div",k,[r(t)?(s(),d(g,{key:0,"runner-data":r(t),"hide-sidebar":""},null,8,["runner-data"])):u("",!0),_(y,{workspace:r(t),loading:r(n),onFormClick:p},null,8,["workspace","loading"])]))}});const L=l(w,[["__scopeId","data-v-b3a84114"]]);export{L as default};
//# sourceMappingURL=Home.b0b99b5e.js.map
