import{r as a,w as r}from"./runnerData.6fca8fdf.js";import"./outputWidgets.225dd371.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="1111b455-2c5c-4527-85a4-a41e93d87803",t._sentryDebugIdIdentifier="sentry-dbid-1111b455-2c5c-4527-85a4-a41e93d87803")}catch{}})();async function u(t){const e=await fetch(`/_pages/${t}`);if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:n}=await e.json();return n?a(n):null}async function c(){const t=await fetch("/_workspace");if(t.status!=200)return r({});const e=await t.json();return r(e)}export{u as f,c as g};
//# sourceMappingURL=api.9155deab.js.map
