import{F as g}from"./PhArrowSquareOut.vue.32437cf7.js";import{d as k,H as v,b as o,eu as u,c as d,u as a,w as n,ev as w,bf as C,aq as m,aC as h,eC as x,f as c,eE as I,v as D}from"./outputWidgets.225dd371.js";import"./index.497bccda.js";import"./index.dd556745.js";import{A as b}from"./index.8e2737d3.js";import{a as y}from"./Text.a0f2d781.js";import{C as H}from"./Card.ed89093a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="d9bb8c3f-5acd-4a08-9110-9ddbab0b0a78",t._sentryDebugIdIdentifier="sentry-dbid-d9bb8c3f-5acd-4a08-9110-9ddbab0b0a78")}catch{}})();const B=k({__name:"HomeContent",props:{loading:{type:Boolean},workspace:{}},emits:["form-click"],setup(t,{emit:r}){const p=t,f=v(()=>{var e,i;return(i=(e=p.workspace)==null?void 0:e.sidebar.filter(s=>s.visible))!=null?i:[]});function _(e){r("form-click",e)}return(e,i)=>{var s;return o(),u("div",{class:"container",style:w({backgroundColor:(s=e.workspace)==null?void 0:s.theme})},[e.loading?(o(),d(a(C),{key:0})):f.value.length===0?(o(),d(a(y),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:n(()=>[m(" There are no public forms available ")]),_:1})):(o(),d(a(b),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:n(()=>[(o(!0),u(h,null,x(f.value,l=>(o(),d(a(H),{key:l.id,class:"form-card",onClick:F=>_(l.path)},{default:n(()=>[c(a(b),{gap:"large",align:"center",justify:"space-between"},{default:n(()=>[c(a(y),{style:{"font-size":"18px","font-weight":"500"}},{default:n(()=>[m(I(l.name),1)]),_:2},1024),c(a(g),{color:"#000",width:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))],4)}}});const j=D(B,[["__scopeId","data-v-e246816b"]]);export{j as H};
//# sourceMappingURL=HomeContent.076519a0.js.map
