import{F as t}from"./Form.12e2d16e.js";import{b1 as c,cm as n}from"./outputWidgets.225dd371.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="350994c1-c4c3-4c68-b79e-a8df36cf6891",e._sentryDebugIdIdentifier="sentry-dbid-350994c1-c4c3-4c68-b79e-a8df36cf6891")}catch{}})();t.useInjectFormItemContext=c;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.c2deb4e1.js.map
