import{g as m}from"./api.9155deab.js";import{P as c}from"./Passwordless.b33ebc4d.js";import{a as f}from"./asyncComputed.8a54909a.js";import{W as p}from"./WidgetsFrame.36ac6684.js";import{d as u,eA as l,eB as _,b as i,eu as y,e as g,u as s,c as b,w as h,ew as w,f as v,v as k}from"./outputWidgets.225dd371.js";import"./runnerData.6fca8fdf.js";import"./url.29c1f37b.js";import"./index.82d7df3b.js";import"./pubsub.3bce7ea8.js";import"./index.480feb65.js";import"./PhArrowClockwise.vue.993c8605.js";import"./CircularLoading.2b1bdb7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="38d74287-f265-4464-8036-a731019f81fb",e._sentryDebugIdIdentifier="sentry-dbid-38d74287-f265-4464-8036-a731019f81fb")}catch{}})();const I={class:"login"},x=u({__name:"Login",setup(e){const t=l(),r=_(),{result:o}=f(m),d=()=>{const{redirect:a,...n}=r.query;if(a){t.push({path:a,query:n,params:r.params});return}t.push({name:"playerKanban",query:n})};return(a,n)=>(i(),y("div",null,[g("div",I,[s(o)?(i(),b(p,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(c,{onDone:d})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const A=k(x,[["__scopeId","data-v-33714d9d"]]);export{A as default};
//# sourceMappingURL=Login.9d83c666.js.map
